# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class FeeUnitEnum(object):

    """Implementation of the 'FeeUnitEnum' enum.

    TODO: type enum description here.

    Attributes:
        PER_STAY: TODO: type description here.
        PER_DAY: TODO: type description here.
        PER_PERSON: TODO: type description here.
        PER_DAY_PER_PERSON: TODO: type description here.
        PER_DAY_PER_PERSON_EXTRA: TODO: type description here.

    """

    PER_STAY = 'PER_STAY'

    PER_DAY = 'PER_DAY'

    PER_PERSON = 'PER_PERSON'

    PER_DAY_PER_PERSON = 'PER_DAY_PER_PERSON'

    PER_DAY_PER_PERSON_EXTRA = 'PER_DAY_PER_PERSON_EXTRA'

