# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class AllowedPetsTypeEnum(object):

    """Implementation of the 'AllowedPetsTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        ALLOWED: TODO: type description here.
        ALLOWEDONREQUEST: TODO: type description here.
        NOTALLOWED: TODO: type description here.

    """

    ALLOWED = 'Allowed'

    ALLOWEDONREQUEST = 'AllowedOnRequest'

    NOTALLOWED = 'NotAllowed'

