# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.fee_tax_mandatory_setting

class FeeTaxValidationSettings(object):

    """Implementation of the 'FeeTaxValidationSettings' model.

    TODO: type model description here.

    Attributes:
        validation_settings (list of FeeTaxMandatorySetting): Model

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "validation_settings":'validationSettings'
    }

    def __init__(self,
                 validation_settings=None):
        """Constructor for the FeeTaxValidationSettings class"""

        # Initialize members of the class
        self.validation_settings = validation_settings


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        validation_settings = None
        if dictionary.get('validationSettings') != None:
            validation_settings = list()
            for structure in dictionary.get('validationSettings'):
                validation_settings.append(apimaticcalculatorlatest.models.fee_tax_mandatory_setting.FeeTaxMandatorySetting.from_dictionary(structure))

        # Return an object of this model
        return cls(validation_settings)


