# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class PaymentPolicyTypeEnum(object):

    """Implementation of the 'PaymentPolicyTypeEnum' enum.

    Full or Split payment. In case of Split payment - it will be 2 payments.
    [SPLIT,FULL]

    Attributes:
        SPLIT: TODO: type description here.
        FULL: TODO: type description here.

    """

    SPLIT = 'SPLIT'

    FULL = 'FULL'

