# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class ReservationParkingTypeEnum(object):

    """Implementation of the 'ReservationParkingTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        NORESERVATIONNEEDED: TODO: type description here.
        NOTPOSSIBLE: TODO: type description here.
        RESERVATIONNEEDED: TODO: type description here.

    """

    NORESERVATIONNEEDED = 'NoReservationNeeded'

    NOTPOSSIBLE = 'NotPossible'

    RESERVATIONNEEDED = 'ReservationNeeded'

