# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class RequesttoBookTestActionEnum(object):

    """Implementation of the 'RequesttoBookTestActionEnum' enum.

    Allowed values for request to book Test action

    Attributes:
        RESERVATION_REQUEST_VOIDED: TODO: type description here.
        RESERVATION_REQUEST: TODO: type description here.

    """

    RESERVATION_REQUEST_VOIDED = 'RESERVATION_REQUEST_VOIDED'

    RESERVATION_REQUEST = 'RESERVATION_REQUEST'

