# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class TaxisTypeEnum(object):

    """Implementation of the 'TaxisTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        SALESTAXINCLUDED: TODO: type description here.
        SALESTAXEXCLUDED: TODO: type description here.

    """

    SALESTAXINCLUDED = 'SalesTaxIncluded'

    SALESTAXEXCLUDED = 'SalesTaxExcluded'

