# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class YieldmodifierEnum(object):

    """Implementation of the 'YieldmodifierEnum' enum.

    TODO: type enum description here.

    Attributes:
        INCREASE_PERCENT: TODO: type description here.
        DECREASE_PERCENT: TODO: type description here.
        INCREASE_AMOUNT: TODO: type description here.
        DECREASE_AMOUNT: TODO: type description here.

    """

    INCREASE_PERCENT = 'INCREASE_PERCENT'

    DECREASE_PERCENT = 'DECREASE_PERCENT'

    INCREASE_AMOUNT = 'INCREASE_AMOUNT'

    DECREASE_AMOUNT = 'DECREASE_AMOUNT'

