# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class SpaceUnitEnum(object):

    """Implementation of the 'SpaceUnitEnum' enum.

    TODO: type enum description here.

    Attributes:
        SQ_M: TODO: type description here.
        SQ_FT: TODO: type description here.

    """

    SQ_M = 'SQ_M'

    SQ_FT = 'SQ_FT'

