# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class KindofInternetTypeEnum(object):

    """Implementation of the 'KindofInternetTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        WIFI: TODO: type description here.
        WIRED: TODO: type description here.

    """

    WIFI = 'WiFi'

    WIRED = 'Wired'

