# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class ManualPolicyTypeEnum(object):

    """Implementation of the 'ManualPolicyTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        PERCENTAGE: TODO: type description here.
        FLAT: TODO: type description here.

    """

    PERCENTAGE = 'PERCENTAGE'

    FLAT = 'FLAT'

