# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class DepositTypeEnum(object):

    """Implementation of the 'DepositTypeEnum' enum.

    First payment deposit type.

    Attributes:
        PERCENTAGE: TODO: type description here.
        FLAT: TODO: type description here.
        NON: TODO: type description here.

    """

    PERCENTAGE = 'PERCENTAGE'

    FLAT = 'FLAT'

    NON = 'NON'

