# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class PaymentGatewaysTypeEnum(object):

    """Implementation of the 'PaymentGatewaysTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        PAYPAL: TODO: type description here.
        AUTHORIZE_NET: TODO: type description here.
        BRIDGE_PAY: TODO: type description here.
        PAY_BOX: TODO: type description here.
        DIBS: TODO: type description here.
        O_GONE: TODO: type description here.
        DOC_DATA: TODO: type description here.
        PAY_GATE: TODO: type description here.

    """

    PAYPAL = 'PAYPAL'

    AUTHORIZE_NET = 'AUTHORIZE_NET'

    BRIDGE_PAY = 'BRIDGE_PAY'

    PAY_BOX = 'PAY_BOX'

    DIBS = 'DIBS'

    O_GONE = 'O_GONE'

    DOC_DATA = 'DOC_DATA'

    PAY_GATE = 'PAY_GATE'

