# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class LocatedParkingTypeEnum(object):

    """Implementation of the 'LocatedParkingTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        ONSITE: TODO: type description here.
        NEARBY: TODO: type description here.

    """

    ONSITE = 'OnSite'

    NEARBY = 'Nearby'

