# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class CreditCardListEnum(object):

    """Implementation of the 'CreditCardListEnum' enum.

    TODO: type enum description here.

    Attributes:
        MASTER_CARD: TODO: type description here.
        VISA: TODO: type description here.
        AMERICAN_EXPRESS: TODO: type description here.
        DINERS_CLUB: TODO: type description here.
        DISCOVER: TODO: type description here.

    """

    MASTER_CARD = 'MASTER_CARD'

    VISA = 'VISA'

    AMERICAN_EXPRESS = 'AMERICAN_EXPRESS'

    DINERS_CLUB = 'DINERS_CLUB'

    DISCOVER = 'DISCOVER'

