# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class BedConfigurationEnum(object):

    """Implementation of the 'BedConfigurationEnum' enum.

    TODO: type enum description here.

    Attributes:
        RMA58: TODO: type description here.
        RMA86: TODO: type description here.
        RMA102: TODO: type description here.
        RMA113: TODO: type description here.
        RMA200: TODO: type description here.
        RMA201: TODO: type description here.
        RMA203: TODO: type description here.
        RMA6032: TODO: type description here.
        RMA33: TODO: type description here.
        RMA26: TODO: type description here.
        RMA6038: TODO: type description here.
        RMA6118: TODO: type description here.
        RMA6119: TODO: type description here.
        RMA6120: TODO: type description here.
        RMA6121: TODO: type description here.
        RMA6122: TODO: type description here.

    """

    RMA58 = 'RMA58'

    RMA86 = 'RMA86'

    RMA102 = 'RMA102'

    RMA113 = 'RMA113'

    RMA200 = 'RMA200'

    RMA201 = 'RMA201'

    RMA203 = 'RMA203'

    RMA6032 = 'RMA6032'

    RMA33 = 'RMA33'

    RMA26 = 'RMA26'

    RMA6038 = 'RMA6038'

    RMA6118 = 'RMA6118'

    RMA6119 = 'RMA6119'

    RMA6120 = 'RMA6120'

    RMA6121 = 'RMA6121'

    RMA6122 = 'RMA6122'

