# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class UserEnum(object):

    """Implementation of the 'UserEnum' enum.

    TODO: type enum description here.

    Attributes:
        PROPERTY_MANAGER: TODO: type description here.
        GUEST: TODO: type description here.

    """

    PROPERTY_MANAGER = 'PROPERTY_MANAGER'

    GUEST = 'GUEST'

