# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class PropertyTypesEnum(object):

    """Implementation of the 'PropertyTypesEnum' enum.

    TODO: type enum description here.

    Attributes:
        PCT101: TODO: type description here.
        PCT102: TODO: type description here.
        PCT103: TODO: type description here.
        PCT104: TODO: type description here.
        PCT105: TODO: type description here.
        PCT106: TODO: type description here.
        PCT107: TODO: type description here.
        PCT108: TODO: type description here.
        PCT109: TODO: type description here.
        PCT110: TODO: type description here.
        PCT111: TODO: type description here.
        PCT112: TODO: type description here.
        PCT113: TODO: type description here.
        PCT114: TODO: type description here.
        PCT115: TODO: type description here.
        PCT116: TODO: type description here.
        PCT117: TODO: type description here.
        PCT118: TODO: type description here.
        PCT119: TODO: type description here.
        PCT12: TODO: type description here.
        PCT120: TODO: type description here.
        PCT121: TODO: type description here.
        PCT122: TODO: type description here.
        PCT123: TODO: type description here.
        PCT124: TODO: type description here.
        PCT125: TODO: type description here.
        PCT126: TODO: type description here.
        PCT127: TODO: type description here.
        PCT128: TODO: type description here.
        PCT14: TODO: type description here.
        PCT15: TODO: type description here.
        PCT16: TODO: type description here.
        PCT18: TODO: type description here.
        PCT19: TODO: type description here.
        PCT20: TODO: type description here.
        PCT21: TODO: type description here.
        PCT22: TODO: type description here.
        PCT23: TODO: type description here.
        PCT25: TODO: type description here.
        PCT26: TODO: type description here.
        PCT27: TODO: type description here.
        PCT28: TODO: type description here.
        PCT29: TODO: type description here.
        PCT3: TODO: type description here.
        PCT30: TODO: type description here.
        PCT31: TODO: type description here.
        PCT32: TODO: type description here.
        PCT33: TODO: type description here.
        PCT34: TODO: type description here.
        PCT35: TODO: type description here.
        PCT36: TODO: type description here.
        PCT37: TODO: type description here.
        PCT4: TODO: type description here.
        PCT40: TODO: type description here.
        PCT41: TODO: type description here.
        PCT44: TODO: type description here.
        PCT45: TODO: type description here.
        PCT46: TODO: type description here.
        PCT5: TODO: type description here.
        PCT50: TODO: type description here.
        PCT51: TODO: type description here.
        PCT52: TODO: type description here.
        PCT6: TODO: type description here.
        PCT7: TODO: type description here.
        PCT8: TODO: type description here.

    """

    PCT101 = 'PCT101'

    PCT102 = 'PCT102'

    PCT103 = 'PCT103'

    PCT104 = 'PCT104'

    PCT105 = 'PCT105'

    PCT106 = 'PCT106'

    PCT107 = 'PCT107'

    PCT108 = 'PCT108'

    PCT109 = 'PCT109'

    PCT110 = 'PCT110'

    PCT111 = 'PCT111'

    PCT112 = 'PCT112'

    PCT113 = 'PCT113'

    PCT114 = 'PCT114'

    PCT115 = 'PCT115'

    PCT116 = 'PCT116'

    PCT117 = 'PCT117'

    PCT118 = 'PCT118'

    PCT119 = 'PCT119'

    PCT12 = 'PCT12'

    PCT120 = 'PCT120'

    PCT121 = 'PCT121'

    PCT122 = 'PCT122'

    PCT123 = 'PCT123'

    PCT124 = 'PCT124'

    PCT125 = 'PCT125'

    PCT126 = 'PCT126'

    PCT127 = 'PCT127'

    PCT128 = 'PCT128'

    PCT14 = 'PCT14'

    PCT15 = 'PCT15'

    PCT16 = 'PCT16'

    PCT18 = 'PCT18'

    PCT19 = 'PCT19'

    PCT20 = 'PCT20'

    PCT21 = 'PCT21'

    PCT22 = 'PCT22'

    PCT23 = 'PCT23'

    PCT25 = 'PCT25'

    PCT26 = 'PCT26'

    PCT27 = 'PCT27'

    PCT28 = 'PCT28'

    PCT29 = 'PCT29'

    PCT3 = 'PCT3'

    PCT30 = 'PCT30'

    PCT31 = 'PCT31'

    PCT32 = 'PCT32'

    PCT33 = 'PCT33'

    PCT34 = 'PCT34'

    PCT35 = 'PCT35'

    PCT36 = 'PCT36'

    PCT37 = 'PCT37'

    PCT4 = 'PCT4'

    PCT40 = 'PCT40'

    PCT41 = 'PCT41'

    PCT44 = 'PCT44'

    PCT45 = 'PCT45'

    PCT46 = 'PCT46'

    PCT5 = 'PCT5'

    PCT50 = 'PCT50'

    PCT51 = 'PCT51'

    PCT52 = 'PCT52'

    PCT6 = 'PCT6'

    PCT7 = 'PCT7'

    PCT8 = 'PCT8'

