# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class AvailableInternetEnum(object):

    """Implementation of the 'AvailableInternetEnum' enum.

    TODO: type enum description here.

    Attributes:
        ALLAREAS: TODO: type description here.
        BUSINESSCENTER: TODO: type description here.
        SOMEROOMS: TODO: type description here.

    """

    ALLAREAS = 'AllAreas'

    BUSINESSCENTER = 'BusinessCenter'

    SOMEROOMS = 'SomeRooms'

