# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class AsynchronouspushmessagetypeEnum(object):

    """Implementation of the 'AsynchronouspushmessagetypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        BP_VALIDATION: TODO: type description here.

    """

    BP_VALIDATION = 'BP_VALIDATION'

