# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class MultiUnitEnum(object):

    """Implementation of the 'MultiUnitEnum' enum.

    Enum for product multyunit type.

    Attributes:
        MLT: TODO: type description here.
        OWN: TODO: type description here.

    """

    MLT = 'MLT'

    OWN = 'OWN'

