# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class PaymentTypeEnum(object):

    """Implementation of the 'PaymentTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        CREDIT_CARD: TODO: type description here.
        MAIL_CHECK: TODO: type description here.
        BOOKING_PAL_MOR: TODO: type description here.

    """

    CREDIT_CARD = 'CREDIT_CARD'

    MAIL_CHECK = 'MAIL_CHECK'

    BOOKING_PAL_MOR = 'BOOKING_PAL_MOR'

