# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class FeetaxTypeEnum(object):

    """Implementation of the 'FeetaxTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        TAXABLE: TODO: type description here.
        NOT_TAXABLE: TODO: type description here.

    """

    TAXABLE = 'TAXABLE'

    NOT_TAXABLE = 'NOT_TAXABLE'

