# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class NearbyAmenitiesEnum(object):

    """Implementation of the 'NearbyAmenitiesEnum' enum.

    List of allowed Nearby Amenities codes

    Attributes:
        ACC1: TODO: type description here.
        ACC203: TODO: type description here.
        ACC65: TODO: type description here.
        HAC199: TODO: type description here.
        RST5: TODO: type description here.

    """

    ACC1 = 'ACC1'

    ACC203 = 'ACC203'

    ACC65 = 'ACC65'

    HAC199 = 'HAC199'

    RST5 = 'RST5'

