# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class RequestToBookDeclineReasonTypeEnum(object):

    """Implementation of the 'RequestToBookDeclineReasonTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        DATES_NOT_AVAILABLE: TODO: type description here.
        NOT_A_GOOD_FIT: TODO: type description here.
        WAITING_FOR_BETTER_RESERVATION: TODO: type description here.
        NOT_COMFORTABLE: TODO: type description here.

    """

    DATES_NOT_AVAILABLE = 'DATES_NOT_AVAILABLE'

    NOT_A_GOOD_FIT = 'NOT_A_GOOD_FIT'

    WAITING_FOR_BETTER_RESERVATION = 'WAITING_FOR_BETTER_RESERVATION'

    NOT_COMFORTABLE = 'NOT_COMFORTABLE'

