# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class ChannelABBEnum(object):

    """Implementation of the 'ChannelABBEnum' enum.

    TODO: type enum description here.

    Attributes:
        BKG: TODO: type description here.
        ABB: TODO: type description here.
        EXP: TODO: type description here.
        EXP_HC: TODO: type description here.
        HAC: TODO: type description here.

    """

    BKG = 'BKG'

    ABB = 'ABB'

    EXP = 'EXP'

    EXP_HC = 'EXP_HC'

    HAC = 'HAC'

