# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class BedroomTypeEnum(object):

    """Implementation of the 'BedroomTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        BEDROOM: TODO: type description here.
        ENUM_LIVING ROOM: TODO: type description here.

    """

    BEDROOM = 'Bedroom'

    ENUM_LIVING_ROOM = 'Living Room'

