# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class FeeEntityTypeEnum(object):

    """Implementation of the 'FeeEntityTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        MANDATORY: TODO: type description here.
        OPTIONAL: TODO: type description here.
        MANDATORY_PAL: TODO: type description here.

    """

    MANDATORY = 'MANDATORY'

    OPTIONAL = 'OPTIONAL'

    MANDATORY_PAL = 'MANDATORY_PAL'

