# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class FeeTypeEnum(object):

    """Implementation of the 'FeeTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        GENERAL: TODO: type description here.
        PET_FEE: TODO: type description here.
        DEPOSIT: TODO: type description here.

    """

    GENERAL = 'GENERAL'

    PET_FEE = 'PET_FEE'

    DEPOSIT = 'DEPOSIT'

