# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class ReservationCommissionsNotificationModel(object):

    """Implementation of the 'ReservationCommissionsNotificationModel' model.

    TODO: type model description here.

    Attributes:
        channel_commission (float): Channel commission
        bp_commission (float): BookingPal commission

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "channel_commission":'channelCommission',
        "bp_commission":'bpCommission'
    }

    def __init__(self,
                 channel_commission=None,
                 bp_commission=None):
        """Constructor for the ReservationCommissionsNotificationModel class"""

        # Initialize members of the class
        self.channel_commission = channel_commission
        self.bp_commission = bp_commission


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        channel_commission = dictionary.get('channelCommission')
        bp_commission = dictionary.get('bpCommission')

        # Return an object of this model
        return cls(channel_commission,
                   bp_commission)


