# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class CreditCardTypeEnum(object):

    """Implementation of the 'CreditCardTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        TRANSMIT: TODO: type description here.
        POST: TODO: type description here.

    """

    TRANSMIT = 'TRANSMIT'

    POST = 'POST'

