# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class TypeEnum(object):

    """Implementation of the 'TypeEnum' enum.

    Cancellation policy type. [FULLY_REFUNDABLE,NON_REFUNDABLE,MANUAL]

    Attributes:
        FULLY_REFUNDABLE: TODO: type description here.
        NON_REFUNDABLE: TODO: type description here.
        MANUAL: TODO: type description here.

    """

    FULLY_REFUNDABLE = 'FULLY_REFUNDABLE'

    NON_REFUNDABLE = 'NON_REFUNDABLE'

    MANUAL = 'MANUAL'

