# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class RequestToBookTypeEnum(object):

    """Implementation of the 'RequestToBookTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        ACCEPT: TODO: type description here.
        DENY: TODO: type description here.

    """

    ACCEPT = 'ACCEPT'

    DENY = 'DENY'

