# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class ImageTagsEnum(object):

    """Implementation of the 'ImageTagsEnum' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_1: TODO: type description here.
        ENUM_2: TODO: type description here.
        ENUM_3: TODO: type description here.
        ENUM_4: TODO: type description here.
        ENUM_5: TODO: type description here.
        ENUM_6: TODO: type description here.
        ENUM_7: TODO: type description here.
        ENUM_8: TODO: type description here.
        ENUM_10: TODO: type description here.
        ENUM_43: TODO: type description here.
        ENUM_11: TODO: type description here.
        ENUM_13: TODO: type description here.
        ENUM_14: TODO: type description here.
        ENUM_37: TODO: type description here.
        ENUM_41: TODO: type description here.
        ENUM_42: TODO: type description here.
        ENUM_50: TODO: type description here.
        ENUM_55: TODO: type description here.
        ENUM_61: TODO: type description here.
        ENUM_70: TODO: type description here.
        ENUM_74: TODO: type description here.
        ENUM_81: TODO: type description here.
        ENUM_82: TODO: type description here.
        ENUM_87: TODO: type description here.
        ENUM_89: TODO: type description here.
        ENUM_90: TODO: type description here.
        ENUM_94: TODO: type description here.
        ENUM_95: TODO: type description here.
        ENUM_96: TODO: type description here.
        ENUM_97: TODO: type description here.
        ENUM_100: TODO: type description here.
        ENUM_102: TODO: type description here.
        ENUM_103: TODO: type description here.
        ENUM_104: TODO: type description here.
        ENUM_106: TODO: type description here.
        ENUM_107: TODO: type description here.
        ENUM_141: TODO: type description here.
        ENUM_108: TODO: type description here.
        ENUM_112: TODO: type description here.
        ENUM_113: TODO: type description here.
        ENUM_114: TODO: type description here.
        ENUM_115: TODO: type description here.
        ENUM_116: TODO: type description here.
        ENUM_124: TODO: type description here.
        ENUM_125: TODO: type description here.
        ENUM_128: TODO: type description here.
        ENUM_131: TODO: type description here.
        ENUM_137: TODO: type description here.
        ENUM_133: TODO: type description here.
        ENUM_134: TODO: type description here.
        ENUM_143: TODO: type description here.
        ENUM_153: TODO: type description here.
        ENUM_154: TODO: type description here.
        ENUM_155: TODO: type description here.
        ENUM_156: TODO: type description here.
        ENUM_157: TODO: type description here.
        ENUM_158: TODO: type description here.
        ENUM_159: TODO: type description here.
        ENUM_160: TODO: type description here.
        ENUM_161: TODO: type description here.
        ENUM_164: TODO: type description here.
        ENUM_165: TODO: type description here.
        ENUM_167: TODO: type description here.
        ENUM_172: TODO: type description here.
        ENUM_173: TODO: type description here.
        ENUM_177: TODO: type description here.
        ENUM_178: TODO: type description here.
        ENUM_179: TODO: type description here.
        ENUM_182: TODO: type description here.
        ENUM_183: TODO: type description here.
        ENUM_184: TODO: type description here.
        ENUM_185: TODO: type description here.
        ENUM_186: TODO: type description here.
        ENUM_187: TODO: type description here.
        ENUM_188: TODO: type description here.
        ENUM_189: TODO: type description here.
        ENUM_190: TODO: type description here.
        ENUM_191: TODO: type description here.
        ENUM_192: TODO: type description here.
        ENUM_193: TODO: type description here.
        ENUM_194: TODO: type description here.
        ENUM_197: TODO: type description here.
        ENUM_198: TODO: type description here.
        ENUM_199: TODO: type description here.
        ENUM_204: TODO: type description here.
        ENUM_205: TODO: type description here.
        ENUM_240: TODO: type description here.
        ENUM_241: TODO: type description here.
        ENUM_242: TODO: type description here.
        ENUM_245: TODO: type description here.
        ENUM_246: TODO: type description here.
        ENUM_247: TODO: type description here.
        ENUM_248: TODO: type description here.
        ENUM_249: TODO: type description here.
        ENUM_250: TODO: type description here.
        ENUM_251: TODO: type description here.
        ENUM_252: TODO: type description here.
        ENUM_253: TODO: type description here.
        ENUM_254: TODO: type description here.
        ENUM_255: TODO: type description here.
        ENUM_256: TODO: type description here.
        ENUM_257: TODO: type description here.
        ENUM_258: TODO: type description here.
        ENUM_259: TODO: type description here.
        ENUM_260: TODO: type description here.
        ENUM_261: TODO: type description here.
        ENUM_262: TODO: type description here.
        ENUM_263: TODO: type description here.
        ENUM_264: TODO: type description here.
        ENUM_265: TODO: type description here.
        ENUM_266: TODO: type description here.
        ENUM_267: TODO: type description here.
        ENUM_268: TODO: type description here.
        ENUM_269: TODO: type description here.
        ENUM_270: TODO: type description here.
        ENUM_271: TODO: type description here.
        ENUM_272: TODO: type description here.
        ENUM_273: TODO: type description here.
        ENUM_274: TODO: type description here.
        ENUM_275: TODO: type description here.
        ENUM_276: TODO: type description here.
        ENUM_277: TODO: type description here.
        ENUM_278: TODO: type description here.
        ENUM_279: TODO: type description here.
        ENUM_280: TODO: type description here.
        ENUM_281: TODO: type description here.
        ENUM_282: TODO: type description here.
        ENUM_283: TODO: type description here.
        ENUM_284: TODO: type description here.
        ENUM_285: TODO: type description here.
        ENUM_286: TODO: type description here.
        ENUM_287: TODO: type description here.
        ENUM_288: TODO: type description here.
        ENUM_289: TODO: type description here.
        ENUM_290: TODO: type description here.
        ENUM_291: TODO: type description here.

    """

    ENUM_1 = 1

    ENUM_2 = 2

    ENUM_3 = 3

    ENUM_4 = 4

    ENUM_5 = 5

    ENUM_6 = 6

    ENUM_7 = 7

    ENUM_8 = 8

    ENUM_10 = 10

    ENUM_43 = 43

    ENUM_11 = 11

    ENUM_13 = 13

    ENUM_14 = 14

    ENUM_37 = 37

    ENUM_41 = 41

    ENUM_42 = 42

    ENUM_50 = 50

    ENUM_55 = 55

    ENUM_61 = 61

    ENUM_70 = 70

    ENUM_74 = 74

    ENUM_81 = 81

    ENUM_82 = 82

    ENUM_87 = 87

    ENUM_89 = 89

    ENUM_90 = 90

    ENUM_94 = 94

    ENUM_95 = 95

    ENUM_96 = 96

    ENUM_97 = 97

    ENUM_100 = 100

    ENUM_102 = 102

    ENUM_103 = 103

    ENUM_104 = 104

    ENUM_106 = 106

    ENUM_107 = 107

    ENUM_141 = 141

    ENUM_108 = 108

    ENUM_112 = 112

    ENUM_113 = 113

    ENUM_114 = 114

    ENUM_115 = 115

    ENUM_116 = 116

    ENUM_124 = 124

    ENUM_125 = 125

    ENUM_128 = 128

    ENUM_131 = 131

    ENUM_137 = 137

    ENUM_133 = 133

    ENUM_134 = 134

    ENUM_143 = 143

    ENUM_153 = 153

    ENUM_154 = 154

    ENUM_155 = 155

    ENUM_156 = 156

    ENUM_157 = 157

    ENUM_158 = 158

    ENUM_159 = 159

    ENUM_160 = 160

    ENUM_161 = 161

    ENUM_164 = 164

    ENUM_165 = 165

    ENUM_167 = 167

    ENUM_172 = 172

    ENUM_173 = 173

    ENUM_177 = 177

    ENUM_178 = 178

    ENUM_179 = 179

    ENUM_182 = 182

    ENUM_183 = 183

    ENUM_184 = 184

    ENUM_185 = 185

    ENUM_186 = 186

    ENUM_187 = 187

    ENUM_188 = 188

    ENUM_189 = 189

    ENUM_190 = 190

    ENUM_191 = 191

    ENUM_192 = 192

    ENUM_193 = 193

    ENUM_194 = 194

    ENUM_197 = 197

    ENUM_198 = 198

    ENUM_199 = 199

    ENUM_204 = 204

    ENUM_205 = 205

    ENUM_240 = 240

    ENUM_241 = 241

    ENUM_242 = 242

    ENUM_245 = 245

    ENUM_246 = 246

    ENUM_247 = 247

    ENUM_248 = 248

    ENUM_249 = 249

    ENUM_250 = 250

    ENUM_251 = 251

    ENUM_252 = 252

    ENUM_253 = 253

    ENUM_254 = 254

    ENUM_255 = 255

    ENUM_256 = 256

    ENUM_257 = 257

    ENUM_258 = 258

    ENUM_259 = 259

    ENUM_260 = 260

    ENUM_261 = 261

    ENUM_262 = 262

    ENUM_263 = 263

    ENUM_264 = 264

    ENUM_265 = 265

    ENUM_266 = 266

    ENUM_267 = 267

    ENUM_268 = 268

    ENUM_269 = 269

    ENUM_270 = 270

    ENUM_271 = 271

    ENUM_272 = 272

    ENUM_273 = 273

    ENUM_274 = 274

    ENUM_275 = 275

    ENUM_276 = 276

    ENUM_277 = 277

    ENUM_278 = 278

    ENUM_279 = 279

    ENUM_280 = 280

    ENUM_281 = 281

    ENUM_282 = 282

    ENUM_283 = 283

    ENUM_284 = 284

    ENUM_285 = 285

    ENUM_286 = 286

    ENUM_287 = 287

    ENUM_288 = 288

    ENUM_289 = 289

    ENUM_290 = 290

    ENUM_291 = 291

