# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class AmenityTypesEnum(object):

    """Implementation of the 'AmenityTypesEnum' enum.

    TODO: type enum description here.

    Attributes:
        ACC111: TODO: type description here.
        ACC112: TODO: type description here.
        ACC113: TODO: type description here.
        ACC114: TODO: type description here.
        ACC115: TODO: type description here.
        ACC116: TODO: type description here.
        ACC117: TODO: type description here.
        ACC118: TODO: type description here.
        ACC119: TODO: type description here.
        ACC120: TODO: type description here.
        ACC123: TODO: type description here.
        ACC14: TODO: type description here.
        ACC24: TODO: type description here.
        ACC25: TODO: type description here.
        ACC27: TODO: type description here.
        ACC28: TODO: type description here.
        ACC29: TODO: type description here.
        ACC31: TODO: type description here.
        ACC32: TODO: type description here.
        ACC33: TODO: type description here.
        ACC39: TODO: type description here.
        ACC40: TODO: type description here.
        ACC41: TODO: type description here.
        ACC42: TODO: type description here.
        ACC45: TODO: type description here.
        ACC47: TODO: type description here.
        ACC5: TODO: type description here.
        ACC50: TODO: type description here.
        ACC54: TODO: type description here.
        ACC55: TODO: type description here.
        ACC56: TODO: type description here.
        ACC57: TODO: type description here.
        ACC59: TODO: type description here.
        ACC73: TODO: type description here.
        ACC74: TODO: type description here.
        ACC82: TODO: type description here.
        ACC90: TODO: type description here.
        ACC95: TODO: type description here.
        HAC1: TODO: type description here.
        HAC101: TODO: type description here.
        HAC116: TODO: type description here.
        HAC122: TODO: type description here.
        HAC14: TODO: type description here.
        HAC149: TODO: type description here.
        HAC15: TODO: type description here.
        HAC154: TODO: type description here.
        HAC156: TODO: type description here.
        HAC157: TODO: type description here.
        HAC159: TODO: type description here.
        HAC16: TODO: type description here.
        HAC160: TODO: type description here.
        HAC165: TODO: type description here.
        HAC168: TODO: type description here.
        HAC173: TODO: type description here.
        HAC176: TODO: type description here.
        HAC186: TODO: type description here.
        HAC193: TODO: type description here.
        HAC195: TODO: type description here.
        HAC196: TODO: type description here.
        HAC197: TODO: type description here.
        HAC198: TODO: type description here.
        HAC202: TODO: type description here.
        HAC204: TODO: type description here.
        HAC21: TODO: type description here.
        HAC22: TODO: type description here.
        HAC226: TODO: type description here.
        HAC228: TODO: type description here.
        HAC230: TODO: type description here.
        HAC231: TODO: type description here.
        HAC232: TODO: type description here.
        HAC233: TODO: type description here.
        HAC234: TODO: type description here.
        HAC236: TODO: type description here.
        HAC237: TODO: type description here.
        HAC238: TODO: type description here.
        HAC239: TODO: type description here.
        HAC241: TODO: type description here.
        HAC242: TODO: type description here.
        HAC246: TODO: type description here.
        HAC25: TODO: type description here.
        HAC254: TODO: type description here.
        HAC26: TODO: type description here.
        HAC262: TODO: type description here.
        HAC265: TODO: type description here.
        HAC269: TODO: type description here.
        HAC272: TODO: type description here.
        HAC273: TODO: type description here.
        HAC280: TODO: type description here.
        HAC282: TODO: type description here.
        HAC283: TODO: type description here.
        HAC29: TODO: type description here.
        HAC292: TODO: type description here.
        HAC301: TODO: type description here.
        HAC309: TODO: type description here.
        HAC310: TODO: type description here.
        HAC312: TODO: type description here.
        HAC316: TODO: type description here.
        HAC32: TODO: type description here.
        HAC327: TODO: type description here.
        HAC33: TODO: type description here.
        HAC334: TODO: type description here.
        HAC34: TODO: type description here.
        HAC342: TODO: type description here.
        HAC345: TODO: type description here.
        HAC348: TODO: type description here.
        HAC36: TODO: type description here.
        HAC37: TODO: type description here.
        HAC41: TODO: type description here.
        HAC42: TODO: type description here.
        HAC44: TODO: type description here.
        HAC45: TODO: type description here.
        HAC49: TODO: type description here.
        HAC5: TODO: type description here.
        HAC50: TODO: type description here.
        HAC5033: TODO: type description here.
        HAC51: TODO: type description here.
        HAC53: TODO: type description here.
        HAC54: TODO: type description here.
        HAC55: TODO: type description here.
        HAC60: TODO: type description here.
        HAC6002: TODO: type description here.
        HAC6008: TODO: type description here.
        HAC6010: TODO: type description here.
        HAC6013: TODO: type description here.
        HAC6014: TODO: type description here.
        HAC6019: TODO: type description here.
        HAC6020: TODO: type description here.
        HAC6024: TODO: type description here.
        HAC6025: TODO: type description here.
        HAC6026: TODO: type description here.
        HAC6027: TODO: type description here.
        HAC6028: TODO: type description here.
        HAC6029: TODO: type description here.
        HAC6030: TODO: type description here.
        HAC6031: TODO: type description here.
        HAC6032: TODO: type description here.
        HAC6033: TODO: type description here.
        HAC6034: TODO: type description here.
        HAC6035: TODO: type description here.
        HAC6036: TODO: type description here.
        HAC6037: TODO: type description here.
        HAC6038: TODO: type description here.
        HAC6039: TODO: type description here.
        HAC6040: TODO: type description here.
        HAC6041: TODO: type description here.
        HAC6042: TODO: type description here.
        HAC6043: TODO: type description here.
        HAC6044: TODO: type description here.
        HAC6045: TODO: type description here.
        HAC6046: TODO: type description here.
        HAC6047: TODO: type description here.
        HAC6048: TODO: type description here.
        HAC6049: TODO: type description here.
        HAC6050: TODO: type description here.
        HAC6051: TODO: type description here.
        HAC6052: TODO: type description here.
        HAC6053: TODO: type description here.
        HAC6054: TODO: type description here.
        HAC6055: TODO: type description here.
        HAC6056: TODO: type description here.
        HAC6057: TODO: type description here.
        HAC6058: TODO: type description here.
        HAC6059: TODO: type description here.
        HAC6060: TODO: type description here.
        HAC6061: TODO: type description here.
        HAC6062: TODO: type description here.
        HAC6063: TODO: type description here.
        HAC6064: TODO: type description here.
        HAC6065: TODO: type description here.
        HAC6066: TODO: type description here.
        HAC6067: TODO: type description here.
        HAC6068: TODO: type description here.
        HAC6069: TODO: type description here.
        HAC6070: TODO: type description here.
        HAC6072: TODO: type description here.
        HAC6073: TODO: type description here.
        HAC6074: TODO: type description here.
        HAC6075: TODO: type description here.
        HAC6076: TODO: type description here.
        HAC6077: TODO: type description here.
        HAC6078: TODO: type description here.
        HAC6079: TODO: type description here.
        HAC6080: TODO: type description here.
        HAC6081: TODO: type description here.
        HAC6082: TODO: type description here.
        HAC6084: TODO: type description here.
        HAC6085: TODO: type description here.
        HAC6086: TODO: type description here.
        HAC6087: TODO: type description here.
        HAC6088: TODO: type description here.
        HAC6089: TODO: type description here.
        HAC6090: TODO: type description here.
        HAC6091: TODO: type description here.
        HAC6092: TODO: type description here.
        HAC6093: TODO: type description here.
        HAC6095: TODO: type description here.
        HAC6096: TODO: type description here.
        HAC6097: TODO: type description here.
        HAC6098: TODO: type description here.
        HAC6099: TODO: type description here.
        HAC61: TODO: type description here.
        HAC6100: TODO: type description here.
        HAC6101: TODO: type description here.
        HAC6102: TODO: type description here.
        HAC6103: TODO: type description here.
        HAC6104: TODO: type description here.
        HAC6105: TODO: type description here.
        HAC6106: TODO: type description here.
        HAC6107: TODO: type description here.
        HAC6108: TODO: type description here.
        HAC6109: TODO: type description here.
        HAC6110: TODO: type description here.
        HAC6111: TODO: type description here.
        HAC6113: TODO: type description here.
        HAC6114: TODO: type description here.
        HAC6115: TODO: type description here.
        HAC6116: TODO: type description here.
        HAC6117: TODO: type description here.
        HAC6118: TODO: type description here.
        HAC6119: TODO: type description here.
        HAC6120: TODO: type description here.
        HAC6121: TODO: type description here.
        HAC6122: TODO: type description here.
        HAC6123: TODO: type description here.
        HAC6124: TODO: type description here.
        HAC6125: TODO: type description here.
        HAC6126: TODO: type description here.
        HAC6127: TODO: type description here.
        HAC6128: TODO: type description here.
        HAC6129: TODO: type description here.
        HAC6130: TODO: type description here.
        HAC6131: TODO: type description here.
        HAC6132: TODO: type description here.
        HAC6133: TODO: type description here.
        HAC6134: TODO: type description here.
        HAC6135: TODO: type description here.
        HAC6136: TODO: type description here.
        HAC6137: TODO: type description here.
        HAC6138: TODO: type description here.
        HAC62: TODO: type description here.
        HAC66: TODO: type description here.
        HAC7: TODO: type description here.
        HAC71: TODO: type description here.
        HAC76: TODO: type description here.
        HAC77: TODO: type description here.
        HAC78: TODO: type description here.
        HAC79: TODO: type description here.
        HAC8: TODO: type description here.
        HAC81: TODO: type description here.
        HAC83: TODO: type description here.
        HAC86: TODO: type description here.
        HAC9: TODO: type description here.
        HAC91: TODO: type description here.
        HAC94: TODO: type description here.
        HAC96: TODO: type description here.
        HAC97: TODO: type description here.
        HAC98: TODO: type description here.
        RMA1: TODO: type description here.
        RMA10: TODO: type description here.
        RMA100: TODO: type description here.
        RMA102: TODO: type description here.
        RMA103: TODO: type description here.
        RMA104: TODO: type description here.
        RMA105: TODO: type description here.
        RMA107: TODO: type description here.
        RMA108: TODO: type description here.
        RMA11: TODO: type description here.
        RMA111: TODO: type description here.
        RMA113: TODO: type description here.
        RMA115: TODO: type description here.
        RMA117: TODO: type description here.
        RMA119: TODO: type description here.
        RMA126: TODO: type description here.
        RMA127: TODO: type description here.
        RMA129: TODO: type description here.
        RMA13: TODO: type description here.
        RMA133: TODO: type description here.
        RMA135: TODO: type description here.
        RMA138: TODO: type description here.
        RMA139: TODO: type description here.
        RMA14: TODO: type description here.
        RMA141: TODO: type description here.
        RMA142: TODO: type description here.
        RMA143: TODO: type description here.
        RMA144: TODO: type description here.
        RMA146: TODO: type description here.
        RMA147: TODO: type description here.
        RMA149: TODO: type description here.
        RMA15: TODO: type description here.
        RMA151: TODO: type description here.
        RMA155: TODO: type description here.
        RMA157: TODO: type description here.
        RMA158: TODO: type description here.
        RMA16: TODO: type description here.
        RMA161: TODO: type description here.
        RMA162: TODO: type description here.
        RMA163: TODO: type description here.
        RMA164: TODO: type description here.
        RMA166: TODO: type description here.
        RMA167: TODO: type description here.
        RMA170: TODO: type description here.
        RMA175: TODO: type description here.
        RMA18: TODO: type description here.
        RMA186: TODO: type description here.
        RMA19: TODO: type description here.
        RMA190: TODO: type description here.
        RMA191: TODO: type description here.
        RMA192: TODO: type description here.
        RMA193: TODO: type description here.
        RMA194: TODO: type description here.
        RMA195: TODO: type description here.
        RMA2: TODO: type description here.
        RMA20: TODO: type description here.
        RMA200: TODO: type description here.
        RMA201: TODO: type description here.
        RMA203: TODO: type description here.
        RMA204: TODO: type description here.
        RMA205: TODO: type description here.
        RMA207: TODO: type description here.
        RMA21: TODO: type description here.
        RMA210: TODO: type description here.
        RMA214: TODO: type description here.
        RMA217: TODO: type description here.
        RMA218: TODO: type description here.
        RMA22: TODO: type description here.
        RMA220: TODO: type description here.
        RMA223: TODO: type description here.
        RMA224: TODO: type description here.
        RMA227: TODO: type description here.
        RMA228: TODO: type description here.
        RMA230: TODO: type description here.
        RMA231: TODO: type description here.
        RMA234: TODO: type description here.
        RMA242: TODO: type description here.
        RMA245: TODO: type description here.
        RMA246: TODO: type description here.
        RMA25: TODO: type description here.
        RMA251: TODO: type description here.
        RMA254: TODO: type description here.
        RMA256: TODO: type description here.
        RMA258: TODO: type description here.
        RMA259: TODO: type description here.
        RMA26: TODO: type description here.
        RMA260: TODO: type description here.
        RMA262: TODO: type description here.
        RMA265: TODO: type description here.
        RMA268: TODO: type description here.
        RMA269: TODO: type description here.
        RMA270: TODO: type description here.
        RMA271: TODO: type description here.
        RMA273: TODO: type description here.
        RMA276: TODO: type description here.
        RMA279: TODO: type description here.
        RMA28: TODO: type description here.
        RMA280: TODO: type description here.
        RMA29: TODO: type description here.
        RMA3: TODO: type description here.
        RMA32: TODO: type description here.
        RMA33: TODO: type description here.
        RMA38: TODO: type description here.
        RMA41: TODO: type description here.
        RMA45: TODO: type description here.
        RMA46: TODO: type description here.
        RMA47: TODO: type description here.
        RMA49: TODO: type description here.
        RMA5: TODO: type description here.
        RMA50: TODO: type description here.
        RMA5005: TODO: type description here.
        RMA5020: TODO: type description here.
        RMA5085: TODO: type description here.
        RMA5086: TODO: type description here.
        RMA5091: TODO: type description here.
        RMA5126: TODO: type description here.
        RMA5145: TODO: type description here.
        RMA55: TODO: type description here.
        RMA56: TODO: type description here.
        RMA57: TODO: type description here.
        RMA58: TODO: type description here.
        RMA59: TODO: type description here.
        RMA6: TODO: type description here.
        RMA60: TODO: type description here.
        RMA6001: TODO: type description here.
        RMA6003: TODO: type description here.
        RMA6004: TODO: type description here.
        RMA6005: TODO: type description here.
        RMA6010: TODO: type description here.
        RMA6012: TODO: type description here.
        RMA6013: TODO: type description here.
        RMA6017: TODO: type description here.
        RMA6018: TODO: type description here.
        RMA6021: TODO: type description here.
        RMA6027: TODO: type description here.
        RMA6028: TODO: type description here.
        RMA6029: TODO: type description here.
        RMA6030: TODO: type description here.
        RMA6031: TODO: type description here.
        RMA6032: TODO: type description here.
        RMA6033: TODO: type description here.
        RMA6034: TODO: type description here.
        RMA6035: TODO: type description here.
        RMA6036: TODO: type description here.
        RMA6037: TODO: type description here.
        RMA6038: TODO: type description here.
        RMA6039: TODO: type description here.
        RMA6040: TODO: type description here.
        RMA6042: TODO: type description here.
        RMA6045: TODO: type description here.
        RMA6046: TODO: type description here.
        RMA6051: TODO: type description here.
        RMA6052: TODO: type description here.
        RMA6053: TODO: type description here.
        RMA6054: TODO: type description here.
        RMA6055: TODO: type description here.
        RMA6056: TODO: type description here.
        RMA6057: TODO: type description here.
        RMA6058: TODO: type description here.
        RMA6059: TODO: type description here.
        RMA6060: TODO: type description here.
        RMA6061: TODO: type description here.
        RMA6062: TODO: type description here.
        RMA6063: TODO: type description here.
        RMA6064: TODO: type description here.
        RMA6065: TODO: type description here.
        RMA6066: TODO: type description here.
        RMA6067: TODO: type description here.
        RMA6068: TODO: type description here.
        RMA6071: TODO: type description here.
        RMA6072: TODO: type description here.
        RMA6073: TODO: type description here.
        RMA6074: TODO: type description here.
        RMA6075: TODO: type description here.
        RMA6076: TODO: type description here.
        RMA6077: TODO: type description here.
        RMA6078: TODO: type description here.
        RMA6079: TODO: type description here.
        RMA6080: TODO: type description here.
        RMA6081: TODO: type description here.
        RMA6082: TODO: type description here.
        RMA6083: TODO: type description here.
        RMA6084: TODO: type description here.
        RMA6085: TODO: type description here.
        RMA6086: TODO: type description here.
        RMA6087: TODO: type description here.
        RMA6088: TODO: type description here.
        RMA6089: TODO: type description here.
        RMA6090: TODO: type description here.
        RMA6091: TODO: type description here.
        RMA6092: TODO: type description here.
        RMA6093: TODO: type description here.
        RMA6094: TODO: type description here.
        RMA6095: TODO: type description here.
        RMA6096: TODO: type description here.
        RMA6097: TODO: type description here.
        RMA6098: TODO: type description here.
        RMA6099: TODO: type description here.
        RMA61: TODO: type description here.
        RMA6100: TODO: type description here.
        RMA6101: TODO: type description here.
        RMA6102: TODO: type description here.
        RMA6103: TODO: type description here.
        RMA6104: TODO: type description here.
        RMA6105: TODO: type description here.
        RMA6106: TODO: type description here.
        RMA6107: TODO: type description here.
        RMA6108: TODO: type description here.
        RMA6109: TODO: type description here.
        RMA6110: TODO: type description here.
        RMA6111: TODO: type description here.
        RMA6112: TODO: type description here.
        RMA6113: TODO: type description here.
        RMA6114: TODO: type description here.
        RMA6115: TODO: type description here.
        RMA6116: TODO: type description here.
        RMA6117: TODO: type description here.
        RMA6118: TODO: type description here.
        RMA6119: TODO: type description here.
        RMA6120: TODO: type description here.
        RMA6121: TODO: type description here.
        RMA6122: TODO: type description here.
        RMA6123: TODO: type description here.
        RMA6124: TODO: type description here.
        RMA6125: TODO: type description here.
        RMA6126: TODO: type description here.
        RMA6127: TODO: type description here.
        RMA6128: TODO: type description here.
        RMA6129: TODO: type description here.
        RMA6130: TODO: type description here.
        RMA6131: TODO: type description here.
        RMA6132: TODO: type description here.
        RMA6133: TODO: type description here.
        RMA6134: TODO: type description here.
        RMA6135: TODO: type description here.
        RMA6136: TODO: type description here.
        RMA6137: TODO: type description here.
        RMA6138: TODO: type description here.
        RMA6139: TODO: type description here.
        RMA6140: TODO: type description here.
        RMA6141: TODO: type description here.
        RMA6142: TODO: type description here.
        RMA6144: TODO: type description here.
        RMA6145: TODO: type description here.
        RMA6146: TODO: type description here.
        RMA6147: TODO: type description here.
        RMA6148: TODO: type description here.
        RMA6149: TODO: type description here.
        RMA6150: TODO: type description here.
        RMA6151: TODO: type description here.
        RMA6152: TODO: type description here.
        RMA6153: TODO: type description here.
        RMA6154: TODO: type description here.
        RMA6155: TODO: type description here.
        RMA6156: TODO: type description here.
        RMA6157: TODO: type description here.
        RMA6158: TODO: type description here.
        RMA63: TODO: type description here.
        RMA64: TODO: type description here.
        RMA67: TODO: type description here.
        RMA68: TODO: type description here.
        RMA69: TODO: type description here.
        RMA7: TODO: type description here.
        RMA72: TODO: type description here.
        RMA77: TODO: type description here.
        RMA78: TODO: type description here.
        RMA8: TODO: type description here.
        RMA80: TODO: type description here.
        RMA81: TODO: type description here.
        RMA85: TODO: type description here.
        RMA86: TODO: type description here.
        RMA88: TODO: type description here.
        RMA89: TODO: type description here.
        RMA9: TODO: type description here.
        RMA91: TODO: type description here.
        RMA92: TODO: type description here.
        RMA94: TODO: type description here.
        RMA97: TODO: type description here.
        RMA98: TODO: type description here.
        RMA99: TODO: type description here.
        RST101: TODO: type description here.
        RST104: TODO: type description here.
        RST105: TODO: type description here.
        RST108: TODO: type description here.
        RST111: TODO: type description here.
        RST112: TODO: type description here.
        RST116: TODO: type description here.
        RST117: TODO: type description here.
        RST120: TODO: type description here.
        RST123: TODO: type description here.
        RST127: TODO: type description here.
        RST129: TODO: type description here.
        RST13: TODO: type description here.
        RST133: TODO: type description here.
        RST134: TODO: type description here.
        RST137: TODO: type description here.
        RST14: TODO: type description here.
        RST149: TODO: type description here.
        RST151: TODO: type description here.
        RST156: TODO: type description here.
        RST157: TODO: type description here.
        RST160: TODO: type description here.
        RST161: TODO: type description here.
        RST169: TODO: type description here.
        RST170: TODO: type description here.
        RST171: TODO: type description here.
        RST172: TODO: type description here.
        RST173: TODO: type description here.
        RST174: TODO: type description here.
        RST175: TODO: type description here.
        RST176: TODO: type description here.
        RST177: TODO: type description here.
        RST178: TODO: type description here.
        RST179: TODO: type description here.
        RST180: TODO: type description here.
        RST181: TODO: type description here.
        RST182: TODO: type description here.
        RST183: TODO: type description here.
        RST184: TODO: type description here.
        RST185: TODO: type description here.
        RST186: TODO: type description here.
        RST187: TODO: type description here.
        RST20: TODO: type description here.
        RST25: TODO: type description here.
        RST34: TODO: type description here.
        RST35: TODO: type description here.
        RST4: TODO: type description here.
        RST5028: TODO: type description here.
        RST60: TODO: type description here.
        RST63: TODO: type description here.
        RST65: TODO: type description here.
        RST67: TODO: type description here.
        RST68: TODO: type description here.
        RST7: TODO: type description here.
        RST71: TODO: type description here.
        RST73: TODO: type description here.
        RST74: TODO: type description here.
        RST79: TODO: type description here.
        RST80: TODO: type description here.
        RST82: TODO: type description here.
        RST86: TODO: type description here.
        RST87: TODO: type description here.
        RST9: TODO: type description here.
        RST92: TODO: type description here.
        RST96: TODO: type description here.

    """

    ACC111 = 'ACC111'

    ACC112 = 'ACC112'

    ACC113 = 'ACC113'

    ACC114 = 'ACC114'

    ACC115 = 'ACC115'

    ACC116 = 'ACC116'

    ACC117 = 'ACC117'

    ACC118 = 'ACC118'

    ACC119 = 'ACC119'

    ACC120 = 'ACC120'

    ACC123 = 'ACC123'

    ACC14 = 'ACC14'

    ACC24 = 'ACC24'

    ACC25 = 'ACC25'

    ACC27 = 'ACC27'

    ACC28 = 'ACC28'

    ACC29 = 'ACC29'

    ACC31 = 'ACC31'

    ACC32 = 'ACC32'

    ACC33 = 'ACC33'

    ACC39 = 'ACC39'

    ACC40 = 'ACC40'

    ACC41 = 'ACC41'

    ACC42 = 'ACC42'

    ACC45 = 'ACC45'

    ACC47 = 'ACC47'

    ACC5 = 'ACC5'

    ACC50 = 'ACC50'

    ACC54 = 'ACC54'

    ACC55 = 'ACC55'

    ACC56 = 'ACC56'

    ACC57 = 'ACC57'

    ACC59 = 'ACC59'

    ACC73 = 'ACC73'

    ACC74 = 'ACC74'

    ACC82 = 'ACC82'

    ACC90 = 'ACC90'

    ACC95 = 'ACC95'

    HAC1 = 'HAC1'

    HAC101 = 'HAC101'

    HAC116 = 'HAC116'

    HAC122 = 'HAC122'

    HAC14 = 'HAC14'

    HAC149 = 'HAC149'

    HAC15 = 'HAC15'

    HAC154 = 'HAC154'

    HAC156 = 'HAC156'

    HAC157 = 'HAC157'

    HAC159 = 'HAC159'

    HAC16 = 'HAC16'

    HAC160 = 'HAC160'

    HAC165 = 'HAC165'

    HAC168 = 'HAC168'

    HAC173 = 'HAC173'

    HAC176 = 'HAC176'

    HAC186 = 'HAC186'

    HAC193 = 'HAC193'

    HAC195 = 'HAC195'

    HAC196 = 'HAC196'

    HAC197 = 'HAC197'

    HAC198 = 'HAC198'

    HAC202 = 'HAC202'

    HAC204 = 'HAC204'

    HAC21 = 'HAC21'

    HAC22 = 'HAC22'

    HAC226 = 'HAC226'

    HAC228 = 'HAC228'

    HAC230 = 'HAC230'

    HAC231 = 'HAC231'

    HAC232 = 'HAC232'

    HAC233 = 'HAC233'

    HAC234 = 'HAC234'

    HAC236 = 'HAC236'

    HAC237 = 'HAC237'

    HAC238 = 'HAC238'

    HAC239 = 'HAC239'

    HAC241 = 'HAC241'

    HAC242 = 'HAC242'

    HAC246 = 'HAC246'

    HAC25 = 'HAC25'

    HAC254 = 'HAC254'

    HAC26 = 'HAC26'

    HAC262 = 'HAC262'

    HAC265 = 'HAC265'

    HAC269 = 'HAC269'

    HAC272 = 'HAC272'

    HAC273 = 'HAC273'

    HAC280 = 'HAC280'

    HAC282 = 'HAC282'

    HAC283 = 'HAC283'

    HAC29 = 'HAC29'

    HAC292 = 'HAC292'

    HAC301 = 'HAC301'

    HAC309 = 'HAC309'

    HAC310 = 'HAC310'

    HAC312 = 'HAC312'

    HAC316 = 'HAC316'

    HAC32 = 'HAC32'

    HAC327 = 'HAC327'

    HAC33 = 'HAC33'

    HAC334 = 'HAC334'

    HAC34 = 'HAC34'

    HAC342 = 'HAC342'

    HAC345 = 'HAC345'

    HAC348 = 'HAC348'

    HAC36 = 'HAC36'

    HAC37 = 'HAC37'

    HAC41 = 'HAC41'

    HAC42 = 'HAC42'

    HAC44 = 'HAC44'

    HAC45 = 'HAC45'

    HAC49 = 'HAC49'

    HAC5 = 'HAC5'

    HAC50 = 'HAC50'

    HAC5033 = 'HAC5033'

    HAC51 = 'HAC51'

    HAC53 = 'HAC53'

    HAC54 = 'HAC54'

    HAC55 = 'HAC55'

    HAC60 = 'HAC60'

    HAC6002 = 'HAC6002'

    HAC6008 = 'HAC6008'

    HAC6010 = 'HAC6010'

    HAC6013 = 'HAC6013'

    HAC6014 = 'HAC6014'

    HAC6019 = 'HAC6019'

    HAC6020 = 'HAC6020'

    HAC6024 = 'HAC6024'

    HAC6025 = 'HAC6025'

    HAC6026 = 'HAC6026'

    HAC6027 = 'HAC6027'

    HAC6028 = 'HAC6028'

    HAC6029 = 'HAC6029'

    HAC6030 = 'HAC6030'

    HAC6031 = 'HAC6031'

    HAC6032 = 'HAC6032'

    HAC6033 = 'HAC6033'

    HAC6034 = 'HAC6034'

    HAC6035 = 'HAC6035'

    HAC6036 = 'HAC6036'

    HAC6037 = 'HAC6037'

    HAC6038 = 'HAC6038'

    HAC6039 = 'HAC6039'

    HAC6040 = 'HAC6040'

    HAC6041 = 'HAC6041'

    HAC6042 = 'HAC6042'

    HAC6043 = 'HAC6043'

    HAC6044 = 'HAC6044'

    HAC6045 = 'HAC6045'

    HAC6046 = 'HAC6046'

    HAC6047 = 'HAC6047'

    HAC6048 = 'HAC6048'

    HAC6049 = 'HAC6049'

    HAC6050 = 'HAC6050'

    HAC6051 = 'HAC6051'

    HAC6052 = 'HAC6052'

    HAC6053 = 'HAC6053'

    HAC6054 = 'HAC6054'

    HAC6055 = 'HAC6055'

    HAC6056 = 'HAC6056'

    HAC6057 = 'HAC6057'

    HAC6058 = 'HAC6058'

    HAC6059 = 'HAC6059'

    HAC6060 = 'HAC6060'

    HAC6061 = 'HAC6061'

    HAC6062 = 'HAC6062'

    HAC6063 = 'HAC6063'

    HAC6064 = 'HAC6064'

    HAC6065 = 'HAC6065'

    HAC6066 = 'HAC6066'

    HAC6067 = 'HAC6067'

    HAC6068 = 'HAC6068'

    HAC6069 = 'HAC6069'

    HAC6070 = 'HAC6070'

    HAC6072 = 'HAC6072'

    HAC6073 = 'HAC6073'

    HAC6074 = 'HAC6074'

    HAC6075 = 'HAC6075'

    HAC6076 = 'HAC6076'

    HAC6077 = 'HAC6077'

    HAC6078 = 'HAC6078'

    HAC6079 = 'HAC6079'

    HAC6080 = 'HAC6080'

    HAC6081 = 'HAC6081'

    HAC6082 = 'HAC6082'

    HAC6084 = 'HAC6084'

    HAC6085 = 'HAC6085'

    HAC6086 = 'HAC6086'

    HAC6087 = 'HAC6087'

    HAC6088 = 'HAC6088'

    HAC6089 = 'HAC6089'

    HAC6090 = 'HAC6090'

    HAC6091 = 'HAC6091'

    HAC6092 = 'HAC6092'

    HAC6093 = 'HAC6093'

    HAC6095 = 'HAC6095'

    HAC6096 = 'HAC6096'

    HAC6097 = 'HAC6097'

    HAC6098 = 'HAC6098'

    HAC6099 = 'HAC6099'

    HAC61 = 'HAC61'

    HAC6100 = 'HAC6100'

    HAC6101 = 'HAC6101'

    HAC6102 = 'HAC6102'

    HAC6103 = 'HAC6103'

    HAC6104 = 'HAC6104'

    HAC6105 = 'HAC6105'

    HAC6106 = 'HAC6106'

    HAC6107 = 'HAC6107'

    HAC6108 = 'HAC6108'

    HAC6109 = 'HAC6109'

    HAC6110 = 'HAC6110'

    HAC6111 = 'HAC6111'

    HAC6113 = 'HAC6113'

    HAC6114 = 'HAC6114'

    HAC6115 = 'HAC6115'

    HAC6116 = 'HAC6116'

    HAC6117 = 'HAC6117'

    HAC6118 = 'HAC6118'

    HAC6119 = 'HAC6119'

    HAC6120 = 'HAC6120'

    HAC6121 = 'HAC6121'

    HAC6122 = 'HAC6122'

    HAC6123 = 'HAC6123'

    HAC6124 = 'HAC6124'

    HAC6125 = 'HAC6125'

    HAC6126 = 'HAC6126'

    HAC6127 = 'HAC6127'

    HAC6128 = 'HAC6128'

    HAC6129 = 'HAC6129'

    HAC6130 = 'HAC6130'

    HAC6131 = 'HAC6131'

    HAC6132 = 'HAC6132'

    HAC6133 = 'HAC6133'

    HAC6134 = 'HAC6134'

    HAC6135 = 'HAC6135'

    HAC6136 = 'HAC6136'

    HAC6137 = 'HAC6137'

    HAC6138 = 'HAC6138'

    HAC62 = 'HAC62'

    HAC66 = 'HAC66'

    HAC7 = 'HAC7'

    HAC71 = 'HAC71'

    HAC76 = 'HAC76'

    HAC77 = 'HAC77'

    HAC78 = 'HAC78'

    HAC79 = 'HAC79'

    HAC8 = 'HAC8'

    HAC81 = 'HAC81'

    HAC83 = 'HAC83'

    HAC86 = 'HAC86'

    HAC9 = 'HAC9'

    HAC91 = 'HAC91'

    HAC94 = 'HAC94'

    HAC96 = 'HAC96'

    HAC97 = 'HAC97'

    HAC98 = 'HAC98'

    RMA1 = 'RMA1'

    RMA10 = 'RMA10'

    RMA100 = 'RMA100'

    RMA102 = 'RMA102'

    RMA103 = 'RMA103'

    RMA104 = 'RMA104'

    RMA105 = 'RMA105'

    RMA107 = 'RMA107'

    RMA108 = 'RMA108'

    RMA11 = 'RMA11'

    RMA111 = 'RMA111'

    RMA113 = 'RMA113'

    RMA115 = 'RMA115'

    RMA117 = 'RMA117'

    RMA119 = 'RMA119'

    RMA126 = 'RMA126'

    RMA127 = 'RMA127'

    RMA129 = 'RMA129'

    RMA13 = 'RMA13'

    RMA133 = 'RMA133'

    RMA135 = 'RMA135'

    RMA138 = 'RMA138'

    RMA139 = 'RMA139'

    RMA14 = 'RMA14'

    RMA141 = 'RMA141'

    RMA142 = 'RMA142'

    RMA143 = 'RMA143'

    RMA144 = 'RMA144'

    RMA146 = 'RMA146'

    RMA147 = 'RMA147'

    RMA149 = 'RMA149'

    RMA15 = 'RMA15'

    RMA151 = 'RMA151'

    RMA155 = 'RMA155'

    RMA157 = 'RMA157'

    RMA158 = 'RMA158'

    RMA16 = 'RMA16'

    RMA161 = 'RMA161'

    RMA162 = 'RMA162'

    RMA163 = 'RMA163'

    RMA164 = 'RMA164'

    RMA166 = 'RMA166'

    RMA167 = 'RMA167'

    RMA170 = 'RMA170'

    RMA175 = 'RMA175'

    RMA18 = 'RMA18'

    RMA186 = 'RMA186'

    RMA19 = 'RMA19'

    RMA190 = 'RMA190'

    RMA191 = 'RMA191'

    RMA192 = 'RMA192'

    RMA193 = 'RMA193'

    RMA194 = 'RMA194'

    RMA195 = 'RMA195'

    RMA2 = 'RMA2'

    RMA20 = 'RMA20'

    RMA200 = 'RMA200'

    RMA201 = 'RMA201'

    RMA203 = 'RMA203'

    RMA204 = 'RMA204'

    RMA205 = 'RMA205'

    RMA207 = 'RMA207'

    RMA21 = 'RMA21'

    RMA210 = 'RMA210'

    RMA214 = 'RMA214'

    RMA217 = 'RMA217'

    RMA218 = 'RMA218'

    RMA22 = 'RMA22'

    RMA220 = 'RMA220'

    RMA223 = 'RMA223'

    RMA224 = 'RMA224'

    RMA227 = 'RMA227'

    RMA228 = 'RMA228'

    RMA230 = 'RMA230'

    RMA231 = 'RMA231'

    RMA234 = 'RMA234'

    RMA242 = 'RMA242'

    RMA245 = 'RMA245'

    RMA246 = 'RMA246'

    RMA25 = 'RMA25'

    RMA251 = 'RMA251'

    RMA254 = 'RMA254'

    RMA256 = 'RMA256'

    RMA258 = 'RMA258'

    RMA259 = 'RMA259'

    RMA26 = 'RMA26'

    RMA260 = 'RMA260'

    RMA262 = 'RMA262'

    RMA265 = 'RMA265'

    RMA268 = 'RMA268'

    RMA269 = 'RMA269'

    RMA270 = 'RMA270'

    RMA271 = 'RMA271'

    RMA273 = 'RMA273'

    RMA276 = 'RMA276'

    RMA279 = 'RMA279'

    RMA28 = 'RMA28'

    RMA280 = 'RMA280'

    RMA29 = 'RMA29'

    RMA3 = 'RMA3'

    RMA32 = 'RMA32'

    RMA33 = 'RMA33'

    RMA38 = 'RMA38'

    RMA41 = 'RMA41'

    RMA45 = 'RMA45'

    RMA46 = 'RMA46'

    RMA47 = 'RMA47'

    RMA49 = 'RMA49'

    RMA5 = 'RMA5'

    RMA50 = 'RMA50'

    RMA5005 = 'RMA5005'

    RMA5020 = 'RMA5020'

    RMA5085 = 'RMA5085'

    RMA5086 = 'RMA5086'

    RMA5091 = 'RMA5091'

    RMA5126 = 'RMA5126'

    RMA5145 = 'RMA5145'

    RMA55 = 'RMA55'

    RMA56 = 'RMA56'

    RMA57 = 'RMA57'

    RMA58 = 'RMA58'

    RMA59 = 'RMA59'

    RMA6 = 'RMA6'

    RMA60 = 'RMA60'

    RMA6001 = 'RMA6001'

    RMA6003 = 'RMA6003'

    RMA6004 = 'RMA6004'

    RMA6005 = 'RMA6005'

    RMA6010 = 'RMA6010'

    RMA6012 = 'RMA6012'

    RMA6013 = 'RMA6013'

    RMA6017 = 'RMA6017'

    RMA6018 = 'RMA6018'

    RMA6021 = 'RMA6021'

    RMA6027 = 'RMA6027'

    RMA6028 = 'RMA6028'

    RMA6029 = 'RMA6029'

    RMA6030 = 'RMA6030'

    RMA6031 = 'RMA6031'

    RMA6032 = 'RMA6032'

    RMA6033 = 'RMA6033'

    RMA6034 = 'RMA6034'

    RMA6035 = 'RMA6035'

    RMA6036 = 'RMA6036'

    RMA6037 = 'RMA6037'

    RMA6038 = 'RMA6038'

    RMA6039 = 'RMA6039'

    RMA6040 = 'RMA6040'

    RMA6042 = 'RMA6042'

    RMA6045 = 'RMA6045'

    RMA6046 = 'RMA6046'

    RMA6051 = 'RMA6051'

    RMA6052 = 'RMA6052'

    RMA6053 = 'RMA6053'

    RMA6054 = 'RMA6054'

    RMA6055 = 'RMA6055'

    RMA6056 = 'RMA6056'

    RMA6057 = 'RMA6057'

    RMA6058 = 'RMA6058'

    RMA6059 = 'RMA6059'

    RMA6060 = 'RMA6060'

    RMA6061 = 'RMA6061'

    RMA6062 = 'RMA6062'

    RMA6063 = 'RMA6063'

    RMA6064 = 'RMA6064'

    RMA6065 = 'RMA6065'

    RMA6066 = 'RMA6066'

    RMA6067 = 'RMA6067'

    RMA6068 = 'RMA6068'

    RMA6071 = 'RMA6071'

    RMA6072 = 'RMA6072'

    RMA6073 = 'RMA6073'

    RMA6074 = 'RMA6074'

    RMA6075 = 'RMA6075'

    RMA6076 = 'RMA6076'

    RMA6077 = 'RMA6077'

    RMA6078 = 'RMA6078'

    RMA6079 = 'RMA6079'

    RMA6080 = 'RMA6080'

    RMA6081 = 'RMA6081'

    RMA6082 = 'RMA6082'

    RMA6083 = 'RMA6083'

    RMA6084 = 'RMA6084'

    RMA6085 = 'RMA6085'

    RMA6086 = 'RMA6086'

    RMA6087 = 'RMA6087'

    RMA6088 = 'RMA6088'

    RMA6089 = 'RMA6089'

    RMA6090 = 'RMA6090'

    RMA6091 = 'RMA6091'

    RMA6092 = 'RMA6092'

    RMA6093 = 'RMA6093'

    RMA6094 = 'RMA6094'

    RMA6095 = 'RMA6095'

    RMA6096 = 'RMA6096'

    RMA6097 = 'RMA6097'

    RMA6098 = 'RMA6098'

    RMA6099 = 'RMA6099'

    RMA61 = 'RMA61'

    RMA6100 = 'RMA6100'

    RMA6101 = 'RMA6101'

    RMA6102 = 'RMA6102'

    RMA6103 = 'RMA6103'

    RMA6104 = 'RMA6104'

    RMA6105 = 'RMA6105'

    RMA6106 = 'RMA6106'

    RMA6107 = 'RMA6107'

    RMA6108 = 'RMA6108'

    RMA6109 = 'RMA6109'

    RMA6110 = 'RMA6110'

    RMA6111 = 'RMA6111'

    RMA6112 = 'RMA6112'

    RMA6113 = 'RMA6113'

    RMA6114 = 'RMA6114'

    RMA6115 = 'RMA6115'

    RMA6116 = 'RMA6116'

    RMA6117 = 'RMA6117'

    RMA6118 = 'RMA6118'

    RMA6119 = 'RMA6119'

    RMA6120 = 'RMA6120'

    RMA6121 = 'RMA6121'

    RMA6122 = 'RMA6122'

    RMA6123 = 'RMA6123'

    RMA6124 = 'RMA6124'

    RMA6125 = 'RMA6125'

    RMA6126 = 'RMA6126'

    RMA6127 = 'RMA6127'

    RMA6128 = 'RMA6128'

    RMA6129 = 'RMA6129'

    RMA6130 = 'RMA6130'

    RMA6131 = 'RMA6131'

    RMA6132 = 'RMA6132'

    RMA6133 = 'RMA6133'

    RMA6134 = 'RMA6134'

    RMA6135 = 'RMA6135'

    RMA6136 = 'RMA6136'

    RMA6137 = 'RMA6137'

    RMA6138 = 'RMA6138'

    RMA6139 = 'RMA6139'

    RMA6140 = 'RMA6140'

    RMA6141 = 'RMA6141'

    RMA6142 = 'RMA6142'

    RMA6144 = 'RMA6144'

    RMA6145 = 'RMA6145'

    RMA6146 = 'RMA6146'

    RMA6147 = 'RMA6147'

    RMA6148 = 'RMA6148'

    RMA6149 = 'RMA6149'

    RMA6150 = 'RMA6150'

    RMA6151 = 'RMA6151'

    RMA6152 = 'RMA6152'

    RMA6153 = 'RMA6153'

    RMA6154 = 'RMA6154'

    RMA6155 = 'RMA6155'

    RMA6156 = 'RMA6156'

    RMA6157 = 'RMA6157'

    RMA6158 = 'RMA6158'

    RMA63 = 'RMA63'

    RMA64 = 'RMA64'

    RMA67 = 'RMA67'

    RMA68 = 'RMA68'

    RMA69 = 'RMA69'

    RMA7 = 'RMA7'

    RMA72 = 'RMA72'

    RMA77 = 'RMA77'

    RMA78 = 'RMA78'

    RMA8 = 'RMA8'

    RMA80 = 'RMA80'

    RMA81 = 'RMA81'

    RMA85 = 'RMA85'

    RMA86 = 'RMA86'

    RMA88 = 'RMA88'

    RMA89 = 'RMA89'

    RMA9 = 'RMA9'

    RMA91 = 'RMA91'

    RMA92 = 'RMA92'

    RMA94 = 'RMA94'

    RMA97 = 'RMA97'

    RMA98 = 'RMA98'

    RMA99 = 'RMA99'

    RST101 = 'RST101'

    RST104 = 'RST104'

    RST105 = 'RST105'

    RST108 = 'RST108'

    RST111 = 'RST111'

    RST112 = 'RST112'

    RST116 = 'RST116'

    RST117 = 'RST117'

    RST120 = 'RST120'

    RST123 = 'RST123'

    RST127 = 'RST127'

    RST129 = 'RST129'

    RST13 = 'RST13'

    RST133 = 'RST133'

    RST134 = 'RST134'

    RST137 = 'RST137'

    RST14 = 'RST14'

    RST149 = 'RST149'

    RST151 = 'RST151'

    RST156 = 'RST156'

    RST157 = 'RST157'

    RST160 = 'RST160'

    RST161 = 'RST161'

    RST169 = 'RST169'

    RST170 = 'RST170'

    RST171 = 'RST171'

    RST172 = 'RST172'

    RST173 = 'RST173'

    RST174 = 'RST174'

    RST175 = 'RST175'

    RST176 = 'RST176'

    RST177 = 'RST177'

    RST178 = 'RST178'

    RST179 = 'RST179'

    RST180 = 'RST180'

    RST181 = 'RST181'

    RST182 = 'RST182'

    RST183 = 'RST183'

    RST184 = 'RST184'

    RST185 = 'RST185'

    RST186 = 'RST186'

    RST187 = 'RST187'

    RST20 = 'RST20'

    RST25 = 'RST25'

    RST34 = 'RST34'

    RST35 = 'RST35'

    RST4 = 'RST4'

    RST5028 = 'RST5028'

    RST60 = 'RST60'

    RST63 = 'RST63'

    RST65 = 'RST65'

    RST67 = 'RST67'

    RST68 = 'RST68'

    RST7 = 'RST7'

    RST71 = 'RST71'

    RST73 = 'RST73'

    RST74 = 'RST74'

    RST79 = 'RST79'

    RST80 = 'RST80'

    RST82 = 'RST82'

    RST86 = 'RST86'

    RST87 = 'RST87'

    RST9 = 'RST9'

    RST92 = 'RST92'

    RST96 = 'RST96'

