# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class TimeCostParkingEnum(object):

    """Implementation of the 'TimeCostParkingEnum' enum.

    TODO: type enum description here.

    Attributes:
        PERHOUR: TODO: type description here.
        PERWEEK: TODO: type description here.
        PERSTAY: TODO: type description here.
        PERDAY: TODO: type description here.

    """

    PERHOUR = 'PerHour'

    PERWEEK = 'PerWeek'

    PERSTAY = 'PerStay'

    PERDAY = 'PerDay'

