# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class WeekendParamEnum(object):

    """Implementation of the 'WeekendParamEnum' enum.

    TODO: type enum description here.

    Attributes:
        DAYS_OF_WEEKEND_SAT_SUN: TODO: type description here.
        DAYS_OF_WEEKEND_FRI_SAT: TODO: type description here.
        DAYS_OF_WEEKEND_FRI_SAT_SUN: TODO: type description here.
        DAYS_OF_WEEKEND_THU_FRI_SAT: TODO: type description here.
        DAYS_OF_WEEKEND_THU_FRI_SAT_SUN: TODO: type description here.

    """

    DAYS_OF_WEEKEND_SAT_SUN = 'DAYS_OF_WEEKEND_SAT_SUN'

    DAYS_OF_WEEKEND_FRI_SAT = 'DAYS_OF_WEEKEND_FRI_SAT'

    DAYS_OF_WEEKEND_FRI_SAT_SUN = 'DAYS_OF_WEEKEND_FRI_SAT_SUN'

    DAYS_OF_WEEKEND_THU_FRI_SAT = 'DAYS_OF_WEEKEND_THU_FRI_SAT'

    DAYS_OF_WEEKEND_THU_FRI_SAT_SUN = 'DAYS_OF_WEEKEND_THU_FRI_SAT_SUN'

