# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class FeeValueTypeEnum(object):

    """Implementation of the 'FeeValueTypeEnum' enum.

    Value Type {FLAT, PERCENT}

    Attributes:
        FLAT: TODO: type description here.
        PERCENT: TODO: type description here.

    """

    FLAT = 'FLAT'

    PERCENT = 'PERCENT'

